Geobricks Downloader
====================

Core functionalities for geospatial data download. Please check the [examples](https://github.com/geobricks/geobricks_downloader/tree/master/examples) section for further details.
